/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'image2', 'sk', {
	alt: 'Alternatívny text',
	btnUpload: 'Odoslať to na server',
	captioned: 'Opísaný obrázok',
	captionPlaceholder: 'Popis',
	infoTab: 'Informácie o obrázku',
	lockRatio: 'Pomer zámky',
	menu: 'Vlastnosti obrázka',
	pathName: 'obrázok',
	pathNameCaption: 'popis',
	resetSize: 'Pôvodná veľkosť',
	resizer: 'Kliknite a potiahnite pre zmenu veľkosti',
	title: 'Vlastnosti obrázka',
	uploadTab: 'Nahrať',
	urlMissing: 'Chýba URL zdroja obrázka.'
} );
